@@ -1,21 +1,26 @@
 from .base import BaseOperation
 from .call import CallOperation
 from .cast import CastOperation
-from .combination import CombinationOperation, RCombinationOperation
+from .combination import CombinationOperation, ImportantCombinationOperation, RCombinationOperation
 from .comparator import ComparatorOperation
+from .extract import ExtractOperation
 from .function import FunctionOperation, ImportantFunctionOperation
 from .getattr import GetAttributeOperation
 from .getitem import GetItemOperation
+from .selector import SelectorOperation
 
 __all__ = (
     "BaseOperation",
     "CallOperation",
+    "CastOperation",
     "CombinationOperation",
     "ComparatorOperation",
-    "CastOperation",
     "FunctionOperation",
-    "ImportantFunctionOperation",
     "GetAttributeOperation",
     "GetItemOperation",
+    "ImportantCombinationOperation",
+    "ImportantFunctionOperation",
     "RCombinationOperation",
+    "SelectorOperation",
+    "ExtractOperation",
 )
